#include <camcapture.h>

/* set video device name */
char *devname = "/dev/video0";


int main(int argc, char *argv[])
{	
	int n;
	/* initiate */
	camcapture_init(devname, 640, 480);
	/* image data struct */
	image_data_t imgdata;
	/* the edgelist */
	image_point_list_t *edgelist;
	
	/* the color to be filtered */
	color_rgb_t filtercolor;
	/* set the filters color to red */
	filtercolor.r = 200;
	filtercolor.g = 0;
	filtercolor.b = 0;
	
	/* the color to draw the edges */
	color_rgb_t blue;
	/* set the color to blue */
	blue.r = 0;
	blue.g = 0;
	blue.b = 255;
	
	/* lets take n frames */
	n = 20;
	while( (n--) > 0 )
	{
		/* Lock video device */
		camcapture_lock();

		/* Get frame */
		camcapture_get_frame(&imgdata);
		
		/* create an empty list */
		edgelist = camcapture_create_point_list();
		
		/* find edges with a filter sensibility of 40,
		 * a raster of 5 and break when found 512 points */
		camcapture_edge_detection_x_col(&imgdata, 
		                                &filtercolor, 
		                                40, 
		                                5, 
		                                512, 
		                                edgelist);

		/* now we use a simple loop through the list to
		 * draw all detected edge points into the image */
		image_point_list_t *tmp = edgelist;
		while( (tmp = tmp->next) != 0)
			camcapture_draw_cross_obj(&imgdata, tmp->data, &blue);
		
		/* the list has to be cleaned up now
		 * all points are deleted, too */
		camcapture_destroy_point_list(edgelist);

		/* store frame in a file */
		camcapture_save_pnm_inc(&imgdata, "frame");

		/* unlock */
		camcapture_unlock();
	}
	
	/* clean up */
	camcapture_destroy();
	
	return 0;
}
