#include <SDL/SDL.h>
#include <stdio.h>
#include "debugdisplay.h"


static SDL_Surface* surface; 
static SDL_Overlay* overlay; 

/* Initialisiert display */
int ddisplay_init(int width, int height)
{
	/* Init video mode */
	if((SDL_Init(SDL_INIT_EVERYTHING) != 0))
	{
		fprintf(stderr, "can't initialize SDL %s\n", SDL_GetError());
		return 0;
	}

	/* Get window surface */
	if( !(surface = SDL_SetVideoMode( width, height, 32, SDL_SWSURFACE )) )
	{
		fprintf(stderr, "failed to set video mode: %s\n", SDL_GetError());
		return 0;
	}

	/* Create YUV-Overlay */
	if(!(overlay = SDL_CreateYUVOverlay(width, height, SDL_YUY2_OVERLAY, surface)))
	{
		fprintf(stderr, "can't create yuv overlay: %s\n", SDL_GetError());
		return 0;
	}
	return 1;
}


/* Testet, ob program weiterlaufen soll, 1 ist ja */
int ddisplay_running()
{
	SDL_Event event;
	while(SDL_PollEvent(&event))
	{
		switch(event.type)
		{
			case SDL_KEYDOWN:
				if (event.key.keysym.sym == SDLK_ESCAPE)
				return 0;
			case SDL_QUIT:
				return 0;
		}
	}
	return 1;
}


/* zeigt ein image_data_t bild an */
void ddisplay_show(image_data_t *imgdata)
{
	SDL_Rect video_rect;

	/* Lock overlay and copy image to window */
	SDL_LockYUVOverlay(overlay);
	memcpy(overlay->pixels[0], imgdata->img, overlay->pitches[0]*overlay->h);

	/* unlock overlay */
	SDL_UnlockYUVOverlay(overlay);

	/* make rect and show */
	video_rect.x = 0;
	video_rect.y = 0;
	video_rect.w = overlay->w;
	video_rect.h = overlay->h;

	SDL_DisplayYUVOverlay(overlay, &video_rect);
}


void ddisplay_destruct()
{
	SDL_FreeYUVOverlay(overlay);
	SDL_Quit();
}
