/**
 * @file mathutil.c
 * @brief Utilities for mathematical stuff
 * @author Florian Schmitt (0schmitt@informatik.uni-hamburg.de)
 * @date Aug-2012
**/
#include "camcapture.h"
#include <math.h>





/**
 * Limits a given double to integer values 0-255
 * @param x Input value as double
 * @return retval An Integer between 0 and 255
**/
int clamp(double x)
{
	int r = x;
	if (r < 0)         return 0;
	else if (r > 255)  return 255;
	else               return r;
}



/**
 * Calculates distance between two values
 * @param v1 value 1
 * @param v2 value 2
 * @return delta between values
**/
int deltaval(int v1, int v2)
{
	int erg;
	erg = v1 - v2;
	return erg;
}

/**
 * Calculates absolute value
 * @param v Value
 * @return absolute value
**/
int absolute(int v)
{
	if(v < 0) return (-1)*v;
	return v;
}




/**
 * Get the distance between two points
 * @param p1 First point
 * @param p2 Second point
 * @return Distance between the two points
**/
int camcapture_math_distance(image_point_t *p1, image_point_t *p2)
{
	int tmp;
	/* calculate distance */
	tmp  = p1->x - p2->x;
	tmp *= tmp;
	tmp += (p1->y - p2->y) * (p1->y - p2->y);
	return (int) sqrt((float)tmp);
}




/**
 * Calculate how far a ball is 
 * @param r_detected Radius of the detected object
 * @param r_real Radius in pixel if the object is 29,7cm away from the camera (1 page of DIN-A4)
 * @return Distance to the ball in m (meters)
**/
float camcapture_math_ball_distance(int r_detected, int r_real)
{
	/* done. */
	if(r_detected == 0) return -1.0f;
	return (float) r_real/r_detected*0.297f;
}
